<?php
// create custom plugin settings menu
add_action('admin_menu', 'flowgallery_create_menu');

function flowgallery_create_menu() {

	//create new top-level menu
	//add_menu_page('FlowGallery Plugin Settings', 'FlowGallery', 'administrator', __FILE__, 'flowgallery_settings_page', plugins_url('/images/icon.png', __FILE__));
    add_submenu_page( 'options-general.php','FlowGallery Plugin Settings','FlowGallery','administrator','flowgallery-options.php','flowgallery_settings_page');

	//call register settings function
	add_action( 'admin_init', 'register_mysettings' );
}

function register_mysettings() {
	//register our settings
	register_setting( 'flowgallery-settings-group', 'flowgallery_use_fancybox' );
	register_setting( 'flowgallery-settings-group', 'flowgallery_use_wp_masonry' );
	register_setting( 'flowgallery-settings-group', 'flowgallery_resample' );
	register_setting( 'flowgallery-settings-group', 'flowgallery_square' );
	register_setting( 'flowgallery-settings-group', 'flowgallery_sorting' );
	register_setting( 'flowgallery-settings-group', 'flowgallery_dropshadow' );
    register_setting( 'flowgallery-settings-group', 'flowgallery_padding', 'flowgallery_padding_validate' );
}

function flowgallery_padding_validate($input) {
    $newinput = trim($input);
    if(!preg_match('/^[0-9]+$/i', $newinput)) {
        $newinput = '0';
    }
    return $newinput;
}

function flowgallery_settings_page() {
?>
<div class="wrap">
<div id="icon-options-general" class="icon32"><br /></div>
<h2>FlowGallery Settings Page</h2>

<form method="post" action="options.php">
    <?php settings_fields( 'flowgallery-settings-group' ); ?>
    <?php do_settings_sections( 'flowgallery-settings-group' ); ?>
    <table class="form-table">
        <tr valign="top">
        <th scope="row">Use fancybox Lightbox?</th>
        <td><input type="checkbox" name="flowgallery_use_fancybox" value="1" <?php echo (get_option('flowgallery_use_fancybox', "1") == 1 ? " checked" : ""); ?> /></td>
        <td>If you use your own lightbox implementation for linked images, disable this option</td>
        </tr>
         
        <tr valign="top">
        <th scope="row">Use Wordpress builtin masonry js?</th>
        <td><input type="checkbox" name="flowgallery_use_wp_masonry" value="1" <?php echo (get_option('flowgallery_use_wp_masonry', "1") == 1 ? " checked" : ""); ?> /></td>
        <td>Newer versions of Wordpress come with masonry javascript built in. If you have an older version and the gallery does not display in flow layout, uncheck this option</td>
        </tr>
        
        <tr valign="top">
        <th scope="row">Use resample for thumbnails?</th>
        <td><input type="checkbox" name="flowgallery_resample" value="1" <?php echo (get_option('flowgallery_resample') == 1 ? " checked" : ""); ?> /></td>
        <td>Resample uses more memory and CPU, but makes nicer thumbnails. Disable if you have performance problems</td>
        </tr>
        
        <tr valign="top">
        <th scope="row">Make square thumbnails?</th>
        <td><input type="checkbox" name="flowgallery_square" value="1" <?php echo (get_option('flowgallery_square') == 1 ? " checked" : ""); ?> /></td>
        <td>will clip left/right or top/bottom depending on landscape / portrait</td>
        </tr>
		
		<tr valign="top">
        <th scope="row">Default Image sorting:</th>
        <td>
		<select name="flowgallery_sorting">
			<option value="oldest" <?php echo (get_option('flowgallery_sorting') == "oldest" ? "selected" : ""); ?>>oldest on top</option>
			<option value="newest" <?php echo (get_option('flowgallery_sorting') == "newest" ? "selected" : ""); ?>>newest on top</option>
			<option value="file_a" <?php echo (get_option('flowgallery_sorting') == "file_a" ? "selected" : ""); ?>>filename ascending</option>
			<option value="file_d" <?php echo (get_option('flowgallery_sorting') == "file_d" ? "selected" : ""); ?>>filename descending</option>			
		</select>
		</td>
        <td>Oldest and newest relate to date uploaded, not picture taken</td>
        </tr>
        
        <tr valign="top">
        <th scope="row">Spacing between images?</th>
        <td><input type="text" style="width: 30px;" name="flowgallery_padding" value="<?php echo get_option('flowgallery_padding','10'); ?>" />px</td>
        <td>The spacing between the images</td>
        </tr>
		
		<tr valign="top">
        <th scope="row">Shadows under images?</th>
        <td><input type="checkbox" name="flowgallery_dropshadow" value="1" <?php echo (get_option('flowgallery_dropshadow','1') == 1 ? " checked" : ""); ?> /></td>
        <td>Disable for flat design</td>
        </tr>
		
        <tr>
        <th colspan="3"><b>Usage:</b> <h3 style="margin-left: 30px;">[flowgallery picWidth=<span style="color: green;">190</span> sort=<span style="color: red;">name_desc</span>]<span style="color: blue;">path/to/folder</span>[/flowgallery]</h3>
        <span style="color: blue;">Path</span> is relative to root folder of your wordpress<br />
        <span style="color: green;">picWidth</span> the width of the thumbnail pictures in pixels<br />
        <span style="color: red;">sort</span> (optional) sorting. Values can be 'name_asc', 'name_desc', 'oldest' or 'newest'. Defaults to oldest</th>
        </tr>

    </table>
    
    <?php submit_button(); ?>

</form>
</div>
<?php }
?>